diff --git a/src/location/doc/src/examples/declarative-places.qdoc b/src/location/doc/src/examples/declarative-places.qdoc
index 1b4b3635ebb5f0ebd10c1b6849b022758da78812..c80ed04c280b54583ddab09d72f1cd4184eb3efd 100644
--- a/src/location/doc/src/examples/declarative-places.qdoc
+++ b/src/location/doc/src/examples/declarative-places.qdoc
@@ -94,12 +94,12 @@
     \codeline
     \snippet places/content/places/CategoryView.qml CategoryModel view 3
 
-    Because a hierarchical model is being used, a \l VisualDataModel is needed to provide
+    Because a hierarchical model is being used, a \l DelegateModel is needed to provide
     navigation functionality.  If flat list model was being used the view could use the
     \l CategoryModel directly.
 
     The view contains a header item that is used as a back button to navigate up the category tree.
-    The \e onClicked handler sets the root index of the \l VisualDataModel to the parent of the
+    The \e onClicked handler sets the root index of the \l DelegateModel to the parent of the
     current index.  Categories are displayed by the \e CategoryDelegate, which provides four
     signals.  The \e onArrowClicked handler sets the root index to the current index causing the
     sub categories of the selected category to be displayed.  The \e onClicked handler emits
diff --git a/src/imports/location/declarativeplaces/qdeclarativesupportedcategoriesmodel.cpp b/src/imports/location/declarativeplaces/qdeclarativesupportedcategoriesmodel.cpp
index acd0d081ba4714456c7da8372051db6ae8b25448..507a4e140417534008b4ff8a95c9d16e83a7ab58 100644
--- a/src/imports/location/declarativeplaces/qdeclarativesupportedcategoriesmodel.cpp
+++ b/src/imports/location/declarativeplaces/qdeclarativesupportedcategoriesmodel.cpp
@@ -82,7 +82,7 @@ QT_USE_NAMESPACE
     \codeline
     \snippet declarative/places.qml CategoryView
 
-    To access the hierarchical category model it is necessary to use a \l VisualDataModel to access
+    To access the hierarchical category model it is necessary to use a \l DelegateModel to access
     the child items.
 */
 
@@ -364,7 +364,7 @@ void QDeclarativeSupportedCategoriesModel::addedCategory(const QPlaceCategory &c
     parentNode->childIds.insert(rowToBeAdded,category.categoryId());
     endInsertRows();
 
     //this is a workaround to deal with the fact that the hasModelChildren field of VisualDataodel
     //does not get updated when a child is added to a model
     beginResetModel();
     endResetModel();
@@ -428,7 +428,7 @@ void QDeclarativeSupportedCategoriesModel::updatedCategory(const QPlaceCategory
         categoryNode->parentId = parentId;
         endMoveRows();
 
         //this is a workaround to deal with the fact that the hasModelChildren field of VisualDataodel
         //does not get updated when an index is updated to contain children
         beginResetModel();
         endResetModel();
@@ -364,7 +364,7 @@ void QDeclarativeSupportedCategoriesModel::addedCategory(const QPlaceCategory &c
     endInsertRows();
 
-    //this is a workaround to deal with the fact that the hasModelChildren field of VisualDataodel
+    //this is a workaround to deal with the fact that the hasModelChildren field of DelegateModel
     //does not get updated when a child is added to a model
     beginResetModel();
@@ -428,7 +428,7 @@ void QDeclarativeSupportedCategoriesModel::updatedCategory(const QPlaceCategory
         endMoveRows();
 
-        //this is a workaround to deal with the fact that the hasModelChildren field of VisualDataodel
+        //this is a workaround to deal with the fact that the hasModelChildren field of DelegateModel
         //does not get updated when an index is updated to contain children
         beginResetModel();